passwords: A password generator and safe

Description Usage Arguments Examples

Description

A password generator and safe

Usage

1
2
3
passwords(master, sites = c("work email", "online bank", "gmail"),
  changes = c(1, 1, 1, 1, 1, 1), how.many.letters = 9,
  how.many.LETTERS = 2, how.many.numbers = 2, how.many.special = 2)

Arguments

master

your master password. Must be numerical with however many digits you want e.g. 7812362029

sites

the names of things for which the password will be generated and saved

changes

a binary vector to describe if you want change a password or not (same length as sites)

how.many.letters

number of lower case letters in your passwords

how.many.LETTERS

number of upper case letters in your passwords

how.many.numbers

number of numbers in your passwords

how.many.special

number of special characters in your passwords

Examples

1
2
 master.password=29852758
 passwords(master.password,sites=c("Work","Bank","Investment","gmail.com","yahoo.com","hotmail.com","visa","spotify"),changes=c(1,1,1,1,1,1,2,1))

duplisea/passwrd documentation built on May 31, 2019, 5:26 a.m.