Description Usage Arguments Examples
A password generator and safe
1 2 3 |
master |
your master password. Must be numerical with however many digits you want e.g. 7812362029 |
sites |
the names of things for which the password will be generated and saved |
changes |
a binary vector to describe if you want change a password or not (same length as sites) |
how.many.letters |
number of lower case letters in your passwords |
how.many.LETTERS |
number of upper case letters in your passwords |
how.many.numbers |
number of numbers in your passwords |
how.many.special |
number of special characters in your passwords |
1 2 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.